//
//  EasyRequest.m
//  ConfluenceCamera
//
//  Created by Mark Brocato on 2/3/12.
//  Copyright (c) 2012 __MyCompanyName__. All rights reserved.
//

#import "EasyRequest.h"

/*
 The following interface uses the private method allowsAnyHTTPSCertificateForHost to
 allow connections to self-signed certificates
 */
@interface NSMutableURLRequest (DummyInterface)

+ (BOOL)allowsAnyHTTPSCertificateForHost:(NSString*)host;

+ (void)setAllowsAnyHTTPSCertificate:(BOOL)allow forHost:(NSString*)host;

@end

@implementation EasyRequest

@synthesize callbackID;
@synthesize response;

/*
 Sends an HTTP request
 arguments: url, bodyContent	
 */
-(void)curl:(NSMutableArray*)arguments withDict:(NSMutableDictionary*)options {
	// the response we're going to send back to JavaScript
	self.response = [[NSMutableString alloc] init];
	
	// the pointer to the callback passed in by PhoneGap
	self.callbackID = [arguments pop];
	
	NSURL *url = [NSURL URLWithString:[arguments objectAtIndex:0]];
    NSData *content = [[arguments objectAtIndex:1] dataUsingEncoding: NSUTF8StringEncoding];
    NSNumber *contentLength = [NSNumber numberWithInt: [content length]];
	
	// allow self-signed certs
	[NSMutableURLRequest setAllowsAnyHTTPSCertificate:YES forHost:[url host]];
	
	NSMutableURLRequest *myRequest = [[NSMutableURLRequest alloc] init];
	[myRequest setValue: @"text/xml" forHTTPHeaderField: @"Content-Type"];
	[myRequest setValue: [contentLength stringValue] forHTTPHeaderField: @"Content-Length"];
	[myRequest setHTTPBody:content];
	[myRequest setURL:url];
	[myRequest setHTTPMethod:@"POST"];
	
	//NSLog(@"Request: %@", [arguments objectAtIndex:1]);
	[[NSURLConnection alloc]initWithRequest:myRequest delegate:self];
}

/*
 NSURLConnection delegate methods
 */
- (void)connection:(NSURLConnection *)connection didReceiveData:(NSData*)data {
	/*
	 This method can be called multiple times if the response is chunked.  So we need to build up the entire response
	 string before returning back to JavaScript.
	 */
	NSString *chunk = [[NSString alloc] initWithBytes:[data bytes] length:[data length] encoding: NSUTF8StringEncoding]; 
	self.response = [self.response stringByAppendingString:chunk];
	//NSLog(@"in didReceiveData, response: %@", self.response);
}

- (void)connectionDidFinishLoading:(NSURLConnection *)connection {
	NSLog(@"Response: %@", self.response);
	[self respond:self.response withSuccess:TRUE];
}

- (void)connection:(NSURLConnection *)connection didFailWithError:(NSError *)error {
	//NSLog(@"in didFailWithError ");
	//NSLog(@"Unresolved error %@, %@", error, [error userInfo]);
	[self respond:[error description] withSuccess:TRUE];
}

/*
 Responds back to JavaScript
 */
- (void) respond:(NSString*) responseString withSuccess:(BOOL) success {
	PluginResult* pluginResult = [PluginResult resultWithStatus:PGCommandStatus_OK messageAsString: responseString];
	
	if(success) {
		@try {
			[self writeJavascript: [pluginResult toSuccessCallbackString:self.callbackID]];
		} @catch (NSException *e) {
			NSLog(@"Caught error %@, %@", [e name], [e description]);
			pluginResult = [PluginResult resultWithStatus:PGCommandStatus_OK messageAsString: [e reason]];
			[self writeJavascript: [pluginResult toErrorCallbackString:self.callbackID]];
		}
	} else {
		[self writeJavascript: [pluginResult toErrorCallbackString:self.callbackID]];
	}
}
@end
