Ext.setup({
	phoneStartupScreen: 'resources/images/startup.png', 
	fullscreen: true
});

/**
 * The ConfluenceCamera application.
 */
Ext.regApplication({
    name: 'app',
    
    /**
     * Notified when Ext is ready.
     */
    launch: function() {
        this.launched = true;
        this.mainLaunch();
    },

    /**
     * Launches the app once both Ext and PhoneGap are ready.
     */
    mainLaunch: function() {
        if (!device || !this.launched) {return;}
        this.views.viewport = new app.views.Viewport();
    }, 
    
    showBrowser: function() {
    	this.views.viewport.layout.setActiveItem(1, {
    		type: 'slide', 
    		direction: 'down', 
    		reveal: true
    	});
    }, 
    
    showCameraForm: function(page) {
    	this.views.viewport.layout.setActiveItem(1);
    	this.views.viewport.cameraDeck.setActiveItem(3, {
    		type: 'slide', 
    		direction: 'left'
    	});
    	this.views.cameraForm.setPage(page);
    }, 
    
    showPageList: function() {
    	this.views.viewport.cameraDeck.setActiveItem(2, {
    		type: 'slide', 
    		direction: 'right'
    	});
    }, 
    
    showPageSearch: function() {
    	this.views.viewport.layout.setActiveItem(1);
    	this.views.viewport.cameraDeck.setActiveItem(1, {
    		type: 'slide', 
    		direction: 'left'
    	});
    }, 
    
    /**
     * Shows the settings card.
     */
    showSettings: function() {
    	this.views.viewport.layout.setActiveItem(0, {
    		type: 'slide',
    		cover: true, 
    		direction: 'up'
    	});
    }, 
    
    /**
     * Logs the user into Confluence.
     * Arguments:
     * @param {String} url, 
     * @param {String} username, 
     * @param {String} password, 
     * @param {Function} success, 
     * @param {Function} fail, 
     * @param {Object} scope
     */
	login: function(args) {
	   if(!app.getSetting('url')) return null;
		Ext.applyIf(args, {
			url: app.getRpcUrl(), 
			username: window.localStorage.getItem('username'), 
			password: window.localStorage.getItem('password'), 
			fail: function(message) {
				Ext.Msg.alert('Authentication Failed.', message || 'Invalid username/password combination.');
			}
		});
		
		app.xmlrpc.XmlRpc.exec({
			url: args.url, 
			method: 'confluence2.login', 
			params: [args.username, args.password],
			success: function(token) {
				app.token = token;
				if(args.success) {
					args.success.call(args.scope, token); 
				}
			}, 
			fail: args.fail, 
			scope: args.scope
		});
	}, 
	
	/**
	 * Returns the XML-RPC url derived from the Confluence base URL stored in application
	 * settings.
	 * @returns {String}
	 */
	getRpcUrl: function() {
		return app.getSetting('url').replace(/\/$/, '') + '/rpc/xmlrpc';
	}, 
	
	getSetting: function(key) {
		return window.localStorage.getItem(key);
	}, 

	putSetting: function(key, value) {
		window.localStorage.setItem(key, value);
	}, 
	
	discardImage: function() {
		Ext.Msg.confirm('Discard Photo', 'Are you sure you want to discard your photo and start over?', function(value) {
			if(value === 'yes') {
				this.views.viewport.cameraDeck.setActiveItem(0, {
		    		type: 'slide', 
		    		direction: 'right', 
		    		callback: function() {
						Ext.getCmp('imagePreview').hide();
		    		}
		    	});
			}
		}, this);
	}
});

//listen for PhoneGap startup
document.addEventListener("deviceready", app.mainLaunch, false);

