app.views.Settings = Ext.extend(Ext.form.FormPanel, {
	title: 'Settings', 
	scroll: 'vertical', 
	iconCls: 'settings-icon', 
	
	initComponent: function() {
		this.usernameField = new Ext.form.Text({
			label: 'Username:', 
			autoCorrect: false, 
			placeHolder: 'user@domain.com'
		});
		
		this.passwordField = new Ext.form.Password({
			label: 'Password:' 
		});
		
		this.urlField = new Ext.form.TextArea({
			autoCorrect: false, 
			placeHolder: 'https://my.domain.com/confluence'
		});
		
		this.photoQualityText = new Ext.Panel({
			html: '<center>50</center>', 
			flex: 1
		});
		
		this.photoQualityField = new Ext.form.Slider({
			minValue: 0, 
			maxValue: 100, 
			value: 50, 
			listeners: {
				drag: this.updatePhotoQualityText, 
				scope: this
			}
		});
		
		this.items = [{
			xtype: 'fieldset', 
			title: 'Confluence Account', 
			defaults: {
				labelAlign: 'left', 
				labelWidth: '40%'
			}, 
			items: [this.usernameField, this.passwordField]
		}, {
			xtype: 'fieldset', 
			title: 'Confluence URL', 
			margin: 0,
			defaults: {
				labelAlign: 'top', 
				labelWidth: '100%'
			}, 
			items: [this.urlField]
		}, {
			bodyStyle: 'border:none', 
			layout: {
				type: 'hbox', 
				pack: 'center'
			}, 
			items: [{
				xtype: 'button', 
				text: 'Test Connection', 
				ui: 'confirm-round',
				iconCls: 'test-connection-icon', 
				handler: this.test, 
				scope: this
			}]
		}, {
			xtype: 'fieldset', 
			title: 'Photo Size', 
			defaults: {
				labelAlign: 'top', 
				labelWidth: '100%'
			}, 
			items: [{
				layout: {
					type: 'hbox', 
					pack: 'center'
				}, 
				items:this.photoQualityText
			}, this.photoQualityField, {
				bodyCls: 'help-text', 
				html: '<center>1MB recommended</center>'
			}]
		}];
		
		this.dockedItems = [{
			xtype: 'toolbar',
			title: 'Settings', 
			ui: 'light', 
			dock: 'top', 
			layout: {
				type: 'hbox', 
				pack: 'right'
			}, 
			items: [{
				xtype: 'button',
				text: 'Done', 
				ui: 'action',
				handler: this.save, 
				scope: this
			}]
		}];
		
		this.on('show', this.load, this);
		
		app.views.Settings.superclass.initComponent.apply(this, arguments);
	}, 
	
	save: function() {
		app.putSetting('username', this.usernameField.getValue());
		app.putSetting('password', this.passwordField.getValue());
		app.putSetting('url', this.urlField.getValue());
		app.putSetting('photoQuality', this.photoQualityField.getValue());
		app.showBrowser();
		// Ext.Msg.alert('Changes Saved.', "Now let's take some photos!", app.showCamera, app);
	}, 
	
	test: function() {
		var success = function() {
			Ext.Msg.alert('Connection Successful', "You're all ready to go!");
		};

		var fail = function(message) {
			Ext.Msg.alert('Login Failed.', message || 'Incorrect username/password combination.');
		};
		
		var rpcUrl = this.urlField.getValue().replace(/\/$/, ''); // remove trailing slash if there is one
		rpcUrl += '/rpc/xmlrpc';
		
		app.login({
			username: this.usernameField.getValue(), 
			password: this.passwordField.getValue(), 
			url: rpcUrl, 
			success: success, 
			fail: fail, 
			scope: this
		});
	}, 
	
	load: function() {
		this.usernameField.setValue(app.getSetting('username'));
		this.passwordField.setValue(app.getSetting('password'));
		this.urlField.setValue(app.getSetting('url'));
		
		var q = app.getSetting('photoQuality') || 50;
		this.photoQualityField.setValue(parseInt(q));

		this.updatePhotoQualityText(null, null, this.photoQualityField.getValue());
	}, 
	
	updatePhotoQualityText: function(slider, thumb, value) {
		var size = (value / 100) * 2;
		this.photoQualityText.el.update('<center>About ' + size + ' MB</center>');
	}
});